%define oname		aMule

%define date		20250525

%if %{date}
%define release		%mkrel -c git%{date} %{rel}
%define tarballver	%{commit}
%define tarballdir	%{commit}
%define tarballgit	+git%{date}
%define commit		9ceeaa68b9727fa38efd9ddcf774b20d39d5a200
%else
%define release		%mkrel %{rel}
%define tarballver	%{version}
%define tarballdir	%{version}
%endif

%define rel	2

Name:		amule
Version:	2.4.0
Release:	%{release}
Summary:	File sharing client compatible with eDonkey
License:	GPLv2
Group:		Networking/File transfer
URL:		https://amule.org
Source:		https://github.com/amule-project/amule/archive/%{tarballdir}/%{name}-%{version}%{?tarballgit}.tar.gz
Patch0:		amule-2.4.0-version_check.patch
Patch1:		amule-cmake-4.0.patch

BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	flex
BuildRequires:	imagemagick
BuildRequires:	desktop-file-utils
BuildRequires:	binutils-devel
BuildRequires:	boost-devel
BuildRequires:	gettext-devel
BuildRequires:	wxgtk-devel
BuildRequires:	pkgconfig(cryptopp)
BuildRequires:	pkgconfig(gdlib) >= 2.0
BuildRequires:	pkgconfig(geoip)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libupnp)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(readline)

%description
aMule is an easy to use multi-platform client for ED2K Peer-to-Peer Network. It
is a fork of xMule, whis was based on emule for Windows. aMule currently
supports (but is not limited to) the following platforms: Linux, *BSD and
MacOSX.

#------------------------------------------------------------------------------

%package	commandline
Summary:	File sharing client compatible with eDonkey
Group:		Networking/File transfer
Requires:	%{name} = %{version}-%{release}

%description	commandline
aMule is an easy to use multi-platform client for ED2K Peer-to-Peer Network. It
is a fork of xMule, whis was based on emule for Windows. aMule currently
supports (but is not limited to) the following platforms: Linux, *BSD and
MacOSX.

This is the command line tool to control aMule remotely (or locally:).

#------------------------------------------------------------------------------

%package	webserver
Summary:	File sharing client compatible with eDonkey
Group:		Networking/File transfer
Requires:	%{name}

%description	webserver
aMule is an easy to use multi-platform client for ED2K Peer-to-Peer Network. It
is a fork of xMule, whis was based on emule for Windows. aMule currently
supports (but is not limited to) the following platforms: Linux, *BSD and
MacOSX.

This is the webserver to control aMule remotely (or locally:).

#------------------------------------------------------------------------------
%prep
%autosetup -p1 -n %{name}-%{tarballver}

# fix GIT version tag name
sed -i -e 's|VERSION "GIT"|VERSION "%{version} GIT"|' CMakeLists.txt

sed -i 's|unset (\${CMAKE_REQUIRED_LIBRARIES})|#unset (\${CMAKE_REQUIRED_LIBRARIES})|' cmake/bfd.cmake

%build
%cmake \
	-DENABLE_BOOST=ON      \
	-DBUILD_AMULECMD=ON    \
	-DBUILD_REMOTEGUI=ON   \
	-DBUILD_WEBSERVER=ON   \
	-DBUILD_CAS=ON         \
	-DBUILD_WXCAS=ON       \
	-DBUILD_ALC=ON         \
	-DBUILD_ALCC=ON        \
	-DBUILD_DAEMON=ON      \
	-DENABLE_IP2COUNTRY=ON \
	-DBUILD_FILEVIEW=ON    \
	-DBUILD_XAS=ON         \
	-DSVNDATE="rev. %{date}"
%cmake_build

%install
%cmake_install

for png in 128x128 48x48 32x32 16x16; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/${png}/apps/
  convert -geometry $png amule.png %{buildroot}%{_iconsdir}/hicolor/${png}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_menudir}

# Fix wrong-script-end-of-line-encoding
perl -pi -e 's/\015$//' %{buildroot}%{_datadir}/doc/%{name}-%{version}/%{name}-win32.HOWTO.txt

mv %{buildroot}%{_bindir}/ed2k %{buildroot}%{_bindir}/ed2k-%{name}
rm -f %{buildroot}%{_datadir}/doc/%{name}-%{version}/man/.cvsignore
rm -rf %{buildroot}%{_datadir}/doc/%{oname}-%{version}
rm -f %{buildroot}%{_libdir}/xchat/plugins/xas.pl

desktop-file-install --vendor="" \
	--add-category="GTK" \
	--add-category="FileTransfer" \
	--dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/*.desktop

%find_lang %{name} --with-man
%find_lang alc --with-man
%find_lang amulegui --with-man
%find_lang cas --with-man
%find_lang ed2k --with-man
%find_lang wxcas --with-man
%find_lang xas --with-man
cat alc.lang amulegui.lang cas.lang ed2k.lang wxcas.lang xas.lang  >> %{name}.lang

%find_lang alcc --with-man
%find_lang amulecmd --with-man
%find_lang amuled --with-man
cat alcc.lang amulecmd.lang amuled.lang  > %{name}-commandline.lang

%find_lang amuleweb --with-man
cat amuleweb.lang  > %{name}-webserver.lang

%post
update-alternatives --install %{_bindir}/ed2k ed2k %{_bindir}/ed2k-%{name} 5

%postun
update-alternatives --remove ed2k %{_bindir}/ed2k-%{name}

%files -f %{name}.lang
%doc docs/{ABOUT-NLS,AUTHORS,Changelog,README,README.Asio.txt,TODO}
%doc docs/{amulesig.txt,EC_Protocol.txt,license.txt,Releases.dia}
%license docs/COPYING
%exclude %{_docdir}/%{name}/INSTALL
%dir %{_datadir}/%{name}
%{_bindir}/%{name}*
%{_bindir}/autostart-xas
%{_bindir}/wxcas
%{_bindir}/cas
%{_bindir}/ed2k-%{name}
%{_bindir}/alc
%{_bindir}/fileview
%{_datadir}/%{name}/skins
%{_datadir}/cas
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/applications/alc.desktop
%{_datadir}/applications/wxcas.desktop
%{_datadir}/pixmaps/%{name}*.xpm
%{_datadir}/pixmaps/alc.xpm
%{_datadir}/pixmaps/wxcas.xpm
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_metainfodir}/org.amule.amule.metainfo.xml
%{_mandir}/man1/alc.1*
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man1/cas.1*
%{_mandir}/man1/ed2k.1*
%{_mandir}/man1/wxcas.1*
%{_mandir}/man1/xas.1*

%files commandline -f %{name}-commandline.lang
%{_bindir}/%{name}cmd
%{_bindir}/alcc
%{_bindir}/%{name}d
%{_mandir}/man1/alcc.1*
%{_mandir}/man1/%{name}cmd.1*
%{_mandir}/man1/%{name}d.1*

%files webserver -f %{name}-webserver.lang
%{_bindir}/%{name}web
%{_datadir}/%{name}/webserver/*
%{_mandir}/man1/amuleweb.1*


%changelog
* Thu Jun 26 2025 daviddavid <daviddavid> 2.4.0-0.git20250525.2.mga10
+ Revision: 2195072
- add patch to fix build with cmake 4.0

* Thu Jun 26 2025 katnatek <katnatek> 2.4.0-0.git20250525.1.mga10
+ Revision: 2194984
- Update to 2025-05-25 commit

* Mon Feb 10 2025 daviddavid <daviddavid> 2.4.0-0.git20250117.1.mga10
+ Revision: 2146780
- update to latest git snapshot: 2.4.0-git20250117

* Sat Jan 04 2025 daviddavid <daviddavid> 2.4.0-0.git20241215.1.mga10
+ Revision: 2135335
- update to latest git snapshot: 2.4.0-git20241215
- switch to wxgtk 3.2

* Sat Jul 16 2022 wally <wally> 2.4.0-0.git20211122.2.mga9
+ Revision: 1869179
- build against wxgtk3.0

* Thu Dec 02 2021 joequant <joequant> 2.4.0-0.git20211122.1.mga9
+ Revision: 1760526
- rebuild with new version using wx-3.1

* Sat Aug 28 2021 joequant <joequant> 2.4.0-0.git20210426.2.mga9
+ Revision: 1743202
- rebuild with new libraries

* Mon May 03 2021 daviddavid <daviddavid> 2.4.0-0.git20210426.1.mga9
+ Revision: 1721107
- update to latest git snapshot: 2.4.0-git20210426

* Tue Dec 15 2020 daviddavid <daviddavid> 2.4.0-0.git20201016.1.mga8
+ Revision: 1657691
- update to latest git snapshot: 2.4.0-git20201016

* Thu Dec 03 2020 luigiwalser <luigiwalser> 2.4.0-0.git20200812.2.mga8
+ Revision: 1652222
- add upstream commit to fix building with libupnp 1.14.0
- rebuild for libupnp

* Mon Sep 14 2020 daviddavid <daviddavid> 2.4.0-0.git20200812.1.mga8
+ Revision: 1626279
- update to latest git snapshot: 2.4.0-git20200812
- switch to wxgtk 3.0 as latest wxgtk 3.1.4 cause crashes (mga#27250)

* Sun Aug 16 2020 wally <wally> 2.4.0-0.git20200518.2.mga8
+ Revision: 1614323
- rebuild for new wxgtk 3.1.4

* Sun May 24 2020 wally <wally> 2.4.0-0.git20200518.1.mga8
+ Revision: 1587350
- update to latest snapshot
- rebuild for new libupnp 1.12.1

* Thu Apr 16 2020 danf <danf> 2.4.0-0.git20191118.4.mga8
+ Revision: 1567878
- Add bfd.patch to fix compilation with binutils 2.34

* Sun Jan 26 2020 wally <wally> 2.4.0-0.git20191118.3.mga8
+ Revision: 1483339
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 2.4.0-0.git20191118.2.mga8
+ Revision: 1475926
- rebuild for readline

* Wed Nov 27 2019 daviddavid <daviddavid> 2.4.0-0.git20191118.1.mga8
+ Revision: 1463052
- update to latest git snapshot: 2.4.0-git20191118

* Tue Nov 26 2019 daviddavid <daviddavid> 2.4.0-0.git20190521.4.mga8
+ Revision: 1463031
- rebuild for new libcryptopp 8.2.0

* Tue Nov 12 2019 wally <wally> 2.4.0-0.git20190521.3.mga8
+ Revision: 1459449
- rebuild for wxgtk 3.1.3

* Mon Jul 08 2019 wally <wally> 2.4.0-0.git20190521.2.mga8
+ Revision: 1419518
- rebuild for wxgtk 3.1.2 with 2.8 compatibility

* Sun Jul 07 2019 wally <wally> 2.4.0-0.git20190521.1.mga8
+ Revision: 1419290
- new snapshot 20190521
- build with gtk3 enabled wxgtk 3.1.2

* Thu May 02 2019 daviddavid <daviddavid> 2.4.0-0.git20190430.1.mga7
+ Revision: 1396124
- update to latest git snapshot: 2.4.0-git20190430

* Tue Jan 01 2019 daviddavid <daviddavid> 2.4.0-0.git20181119.1.mga7
+ Revision: 1348050
- update to latest git snapshot: 2.4.0-git20181119
- add patch to fix build with new libupnp >= 1.8
- disable NewVersionCheck by Default
+ luigiwalser <luigiwalser>
- rebuild for libupnp

* Tue Oct 16 2018 wally <wally> 2.4.0-0.git20180521.2.mga7
+ Revision: 1321006
- rebuild for new boost 1.68.0

* Sun Sep 16 2018 daviddavid <daviddavid> 2.4.0-0.git20180521.1.mga7
+ Revision: 1259210
- update to latest git snapshot: 2.4.0-git20180521
- rebuild for new libcryptopp 7.0.0

* Mon Dec 25 2017 wally <wally> 2.4.0-0.git20161207.5.mga7
+ Revision: 1184649
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 2.4.0-0.git20161207.4.mga7
+ Revision: 1178308
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 2.4.0-0.git20161207.3.mga7
+ Revision: 1154670
- rebuild with latest boost

* Sat Jun 03 2017 akien <akien> 2.4.0-0.git20161207.2.mga6
+ Revision: 1106082
- Rebuild for wxgtk 3.0.3.1

* Sat Jan 14 2017 daviddavid <daviddavid> 2.4.0-0.git20161207.1.mga6
+ Revision: 1081613
- update to latest git snapshot: 2.4.0-git20161207
- rebuild for new libcryptopp (mga#20120)

* Tue Oct 04 2016 daviddavid <daviddavid> 2.4.0-0.git20160926.1.mga6
+ Revision: 1058695
- update to latest git snapshot: 2.4.0-git20160926
- port to wxgtk3

* Sat Jul 09 2016 daviddavid <daviddavid> 2.4.0-0.git20160607.1.mga6
+ Revision: 1039947
- update to latest git snapshot: 2.4.0-git20160607
- rebuild against fixed libgd

* Wed Apr 27 2016 daviddavid <daviddavid> 2.4.0-0.git20160416.1.mga6
+ Revision: 1006892
- new version: 2.4.0-git20160416 (pre-release)
  * commit: 393acf5ce78dfdabd7316c44a78511db1c7bae74

* Wed Apr 27 2016 daviddavid <daviddavid> 2.4.0-0.git20160103.2.mga6
+ Revision: 1006876
- rebuild against libcryptopp 5.6.3 (fixes mga#18272)

* Mon Jan 04 2016 daviddavid <daviddavid> 2.4.0-0.git20160103.1.mga6
+ Revision: 919646
- new version: 2.4.0-git20160103 (pre-release)
  * commit: 13596819eeaf2334ad1a99981c6e1e2f8ddb953b
- update Source URL
- enable boost support

* Thu Sep 03 2015 cjw <cjw> 2.3.1-13.mga6
+ Revision: 872617
- rebuild with gcc 5

* Mon Feb 16 2015 oden <oden> 2.3.1-12.mga5
+ Revision: 815140
- rebuilt for libgd-2.1.1

* Wed Oct 15 2014 umeabot <umeabot> 2.3.1-11.mga5
+ Revision: 739213
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 luigiwalser <luigiwalser> 2.3.1-10.mga5
+ Revision: 685710
- move rename macro usage to correct place in spec file
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sun Mar 30 2014 david-david <david-david> 2.3.1-8.mga5
+ Revision: 610360
- use better icon amule from tarball
- add BR imagemagick
- update License
- update link url for Source

* Sat Oct 19 2013 umeabot <umeabot> 2.3.1-7.mga4
+ Revision: 526042
- Mageia 4 Mass Rebuild

* Mon Jun 03 2013 fwang <fwang> 2.3.1-6.mga4
+ Revision: 435780
- rebuild for new libpng

* Tue May 28 2013 oden <oden> 2.3.1-5.mga4
+ Revision: 429280
- rebuilt against libgd.so.3

* Sun Mar 17 2013 lmenut <lmenut> 2.3.1-4.mga3
+ Revision: 403587
- rebuild for new rpm-mageia-setup (mga #9055)

* Fri Jan 11 2013 umeabot <umeabot> 2.3.1-3.mga3
+ Revision: 345533
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 sander85 <sander85> 2.3.1-2.mga3
+ Revision: 341146
- Rebuild with fixed libcryptopp

* Sat Jan 28 2012 kamil <kamil> 2.3.1-1.mga2
+ Revision: 202574
- new version 2.3.1
- use %%find_lang for man-pages
- clean .spec

* Mon Oct 31 2011 dmorgan <dmorgan> 2.3.1-0.rc2.1.mga2
+ Revision: 160520
- New version 2.3.1 rc2

* Wed Sep 21 2011 fwang <fwang> 2.3.1-0.rc1.4.mga2
+ Revision: 146203
- rebuild for new libpng
- rebuild for new libupnp
+ ahmad <ahmad>
- Replace libgeoip-devel with geoip-devel

* Sun May 08 2011 dmorgan <dmorgan> 2.3.1-0.rc1.2.mga1
+ Revision: 95964
- Remove PLF Reason

* Sun May 08 2011 dmorgan <dmorgan> 2.3.1-0.rc1.1.mga1
+ Revision: 95963
- Fix file list
- Fix typo
- Update to 2.3.1 Rc1
- Do not apply patch0
- imported package amule


* Thu Aug 19 2010 Götz Waschk <goetz@zarb.org> 2.2.6-4plf2011.0
- update URL
- fix build with new wxGTK

* Tue Apr 27 2010 Götz Waschk <goetz@zarb.org> 2.2.6-3plf2010.1
- rebuild for new binutils

* Wed Nov 25 2009 Götz Waschk <goetz@zarb.org> 2.2.6-2plf2010.1
- rebuild for new binutils

* Wed Sep 23 2009 Götz Waschk <goetz@zarb.org> 2.2.6-1plf2010.0
- update file list
- new version

* Mon May 18 2009 Guillaume Bedot <littletux@zarb.org> 2.2.5-1plf2010.0
- New release, includes bugfix

* Tue Apr 14 2009 Götz Waschk <goetz@zarb.org> 2.2.4-1plf2009.1
- enable optimization
- new version

* Wed Feb 11 2009 Götz Waschk <goetz@zarb.org> 2.2.3-2plf2009.1
- rebuild for new binutils

* Tue Dec 30 2008 Götz Waschk <goetz@zarb.org> 2.2.3-1plf2009.1
- build with binutils
- update license
- new version

* Fri Nov  7 2008 Götz Waschk <goetz@zarb.org> 2.2.2-2plf2009.1
- enable UPNP and GeoIP support

* Tue Aug 12 2008 Götz Waschk <goetz@zarb.org> 2.2.2-1plf2009.0
- new version

* Thu Jun 12 2008 Götz Waschk <goetz@zarb.org> 2.2.1-1plf2009.0
- update file list
- depend on cryptopp
- drop old menu
- drop patches
- new version

* Fri Oct 12 2007 Götz Waschk <goetz@zarb.org> 2.1.3-4plf2008.1
- fix desktop entries
- fix buildrequires (bug #148)

* Fri Dec 29 2006 Götz Waschk <goetz@zarb.org> 2.1.3-3plf2007.1
- patch for wxgtk 2.8

* Mon Jun 19 2006 Götz Waschk <goetz@zarb.org> 2.1.3-2plf2007.0
- xdg menu

* Mon Jun 12 2006 Götz Waschk <goetz@zarb.org> 2.1.3-1plf2007.0
- New release 2.1.3

* Sun May 28 2006 Nicolas Lécureuil <neoclust@zarb.org> 2.1.2-1plf
- New version 2.1.2

* Thu Mar 23 2006 Götz Waschk <goetz@zarb.org> 2.1.1-2plf
- update file list
- add amule daemon

* Sat Mar 18 2006 Götz Waschk <goetz@zarb.org> 2.1.1-1plf
- New release 2.1.1

* Mon Jan 23 2006 Götz Waschk <goetz@zarb.org> 2.1.0-2plf
- fix buildrequires
- simplify configure call
- add amule remote gui

* Mon Jan 02 2006 Nicolas Lécureuil <neoclust@zarb.org> 2.1.0-1plf
- 2.1.0  The "I just teased you with this release till 2006" version

* Wed Nov 16 2005 Nicolas Lécureuil <neoclust@zarb.org> 2.1.0-0.20051116.1plf
- Sync with svn

* Wed Nov 09 2005 Nicolas Lécureuil <neoclust@zarb.org> 2.0.3-4plf
- fix macros %%datadir/man => %%_mandir
- fix %%buildroot but doesn't know why it does not work for cat 
- %%mkrel

* Thu Oct 13 2005 Götz Waschk <goetz@zarb.org> 2.0.3-3plf
- Rebuild

* Thu Jun 16 2005 Nicolas Lécureuil <neoclust@zarb.org> 2.0.3-2plf
- Rebuild 

* Thu Jun 16 2005 Nicolas Lécureuil <neoclust@zarb.org> 2.0.3-1plf
- New release 2.0.3
   - The "Hell 2.0.3: Now with improved daemons!" version

* Sun Jun 05 2005 Nicolas Lécureuil <neoclust@zarb.org> 2.0.2-1plf
-  New release 2.0.2

* Wed May 18 2005 Nicolas Lécureuil <neoclust@zarb.org> 2.0.1-1plf
- New release 2.0.1

* Sat May 14 2005 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-5plf
- s/Mandrakelinux/Mandriva
- Fix wrong-script-end-of-line-encoding to make Plouf_Lint Happy

* Thu May 12 2005 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-4plf
- Fix BuildReqires 

* Wed May 11 2005 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-3plf
- Fix Spec for Mdk 10.1 and 10.2

* Wed May 04 2005 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-2plf
- Fix BuildRequires
- Fix Menu for previous Mandriva releases

* Tue May 03 2005 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-1plf
- 2.0.0 
- Fix Files Section
- Fix build for previous Mdk releases ( Thanks littletux )

* Tue Mar 10 2005 trem <trem@zarb.org> 2.0.0-0.rc8.6plf
- Fix Requires

* Fri Dec 24 2004 trem <trem@zarb.org> 2.0.0-0.rc8.5plf
- Fix lib for amd64

* Wed Dec 22 2004 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-0.rc8.4plf
- Fix build for 10.1

* Wed Dec 22 2004 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-0.rc8.3plf
- Removing utf8 option still it doesn't work well

* Wed Dec 22 2004 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-0.rc8.2plf
- Fix Requires

* Wed Dec 22 2004 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-0.rc8.1plf
- Rc8

* Tue Dec 21 2004 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-0.rc7.4plf
- Fix build for previous mandrake release

* Fri Oct 22 2004 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-0.rc7.3plf
- Fixing reason for PLF
- Removing Xchat Script (Thanks to Pterjan && Littletux)
- Updating German README.update.urpmi ( From Steffen Barszus)

* Fri Oct 22 2004 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-0.rc7.2plf
- Adding reason for PLF

* Wed Oct 20 2004 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-0.rc7.1plf
- 2.0.0-0.rc7 
- Fix %%doc

* Sun Oct 10 2004 Nicolas Lécureuil <neoclust@zarb.org> 2.0.0-0.rc6.2plf
- enabling littletux utf8 patch    ---> littletux Roxx 
- fixing README.update.urpmi

* Sun Oct 10 2004 trem <trem@zarb.org> 2.0.0-0.rc6.1plf
- 2.0.0-0.rc6
- fix some Buildrequires

* Tue Aug 31 2004 Guillaume Bedot <littletux@zarb.org> 2.0.0-0.rc5.1plf
- last rc spec contributed by neoclust
- added webserver package and README.update.urpmi

* Wed Feb 25 2004 Götz Waschk <goetz@plf.zarb.org> 1.2.6-3plf
- build with wx_base

* Tue Feb 24 2004 Götz Waschk <goetz@plf.zarb.org> 1.2.6-2plf
- fix menu for mdk 10.0

* Tue Feb 24 2004 Götz Waschk <goetz@plf.zarb.org> 1.2.6-1plf
- new version

* Thu Jan 22 2004 Götz Waschk <goetz@plf.zarb.org> 1.2.4-1plf
- new version

* Fri Jan  2 2004 Götz Waschk <goetz@plf.zarb.org> 1.2.3-1plf
- new version

* Sun Dec 14 2003 Götz Waschk <goetz@plf.zarb.org> 1.2.1-1plf
- fix docs section
- drop wget requirement
- buildrequires curl-devel
- new version

* Fri Nov 28 2003 Götz Waschk <goetz@plf.zarb.org> 1.2.0-1plf
- new version

* Wed Oct 22 2003 Götz Waschk <goetz@plf.zarb.org> 1.1.0-1plf
- new version

* Fri Oct 17 2003 Götz Waschk <goetz@plf.zarb.org> 1.0.9-1plf
- new version

* Sat Oct 11 2003 Götz Waschk <goetz@plf.zarb.org> 1.0.8-1plf
- new version

* Sat Oct  4 2003 Götz Waschk <goetz@plf.zarb.org> 1.0.7-1plf
- add conflict with older xmule without alternativized /usr/bin/ed2k
- new version

* Thu Sep 25 2003 Götz Waschk <goetz@plf.zarb.org> 1.0.6-1plf
- initial aMule package

* Wed Aug 27 2003 Götz Waschk <goetz@plf.zarb.org> 1.6.0-1plf
- switch to wxGTK2.4
- new version

* Fri Jul 11 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.5.5-1plf
- 1.5.5

* Sun Jul 06 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.5.4-1plf
- 1.5.4

* Fri Jul 04 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.5.3-2plf
- "add changelog, /me sux" thanx Nanar for the suggestion :-)

* Fri Jul 04 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.5.3-1plf
- Switch to unstable 1.5.3
  Works fine and fixes a lot of bugs !

* Tue May 27 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.4.0-1plf
- renamed to xMule
- 1.4.0

* Tue May 20 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.3.1-1plf
- unstable version 1.3.1 (fixes some bugs like segfault on exit)

* Wed May 14 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.2.1-2plf
- Require wget (thanks houpla)

* Mon Apr 28 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.2.1-1plf
- 1.2.1
- Don't need anymore to patch configure for gtk2

* Mon Apr 21 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.2.0-1plf
- 1.2.0
- removed French translation (included upstream)
- removed gtk2 patch (merged upstream)

* Thu Apr 03 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.1.13c-2plf
- added BuildRequires libexpat-devel zlib1-devel libgtk+-x11-2.0_0-devel
  libglib2.0_0-devel

* Tue Apr 01 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.1.13c-1plf
- 1.1.13c
- added a partial French translation

* Sat Mar 29 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.1.13-1plf
- new version
- drop patch removing systray integration
- add patch for compilation of systray with gtk2
- drop patch for wx 2.5 compatibility

* Sun Mar 23 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.1.12-1plf
- new version
- lmule changelog states "Lmule probably compiles with gtk2 again.."
  There are less errors but it still doesn't, so I keep the patch dropping
  systray support.
  
* Fri Mar 21 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.1.11b-2plf
- use wxGTK from cvs

* Thu Mar 20 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.1.11b-1.plf
- new version
- use find_lang

* Wed Mar 19 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.1.11-1plf
- new version

* Tue Mar 18 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.1.10-1plf
- new version
- updated patch

* Sun Mar 16 2003 Pascal Terjan <CMoi@tuxfamily.org> 1.1.8-1plf
- initial release
- patch removing systray so it compile
